@@ -28,8 +28,8 @@
   setOperator( '==',   type = 'relational', inverse = '!=', rel.type = 'eq' )
   setOperator( '!=',   type = 'relational', inverse = '==', rel.type = 'ne' )
   setOperator( '%in%', type = 'relational', rel.type = 'eq' )  # %!in% 
-  # setOperator( '%in%' , type = 'relational', inverse='%!in%', rel.type = 'eq' )
-  # setOperator( '%!in%', type = 'relational', inverse='%in%' , rel.type = 'ne' )
+  setOperator( '%in%' , type = 'relational', inverse='%!in%', rel.type = 'eq' )
+  setOperator( '%!in%', type = 'relational', inverse='%in%' , rel.type = 'ne' )
 
 
   setOperator( '!',  type = 'logical' ) # inverse = identity, !?    
